Module feed::channels
[−]
[src]
All the structs for channels.
Modules
| category |
The fields under category can be retrieved by using the methods under
|
| category_builder |
The fields can be set for category by using the methods under
|
| channel |
The fields under channels can be retrieved by using the methods under |
| channel_builder |
The fields can be set for channels by using the methods under |
| cloud |
The fields under cloud can be retrieved by using the methods under |
| cloud_builder |
The fields can be set for cloud by using the methods under |
| enclosure |
The fields under enclosure can be retrieved by using the methods under |
| enclosure_builder |
The fields can be set for enclosure by using the methods under |
| guid |
The fields under guid can be retrieved by using the methods under |
| guid_builder |
The fields can be set for guid by using the methods under |
| image |
The fields under image can be retrieved by using the methods under |
| image_builder |
The fields under image can be retrieved by using the methods under |
| item |
The fields under item can be retrieved by using the methods under |
| item_builder |
The fields can be set for item by using the methods under |
| source |
The fields under source can be retrieved by using the methods under |
| source_builder |
The fields can be set for source by using the methods under |
| text_input |
The fields under text input can be retrieved by using the methods under
|
| text_input_builder |
The fields can be set for text input by using the methods
under |
Structs
| Category |
This |
| CategoryBuilder |
This |
| Channel |
This |
| ChannelBuilder |
This |
| Cloud |
This |
| CloudBuilder |
This |
| Enclosure |
This |
| EnclosureBuilder |
This |
| Guid |
This |
| GuidBuilder |
This |
| Image |
This |
| ImageBuilder |
This |
| Item |
This |
| ItemBuilder |
This |
| Source |
This |
| SourceBuilder |
This |
| TextInput |
This |
| TextInputBuilder |
This |